@@ -24,7 +24,7 @@ try:
 except ImportError:
     import Image
 
-__version__ = '1.0.6'
+__version__ = '1.1.0'
 
 PROGRAM_NAME = 'picopt'
 
@@ -35,6 +35,7 @@ ARCHIVE_TMP_DIR_PREFIX = PROGRAM_NAME+'_tmp_'
 ARCHIVE_TMP_DIR_TEMPLATE = ARCHIVE_TMP_DIR_PREFIX+'%s'
 NEW_ARCHIVE_SUFFIX = '%s-optimized.cbz' % PROGRAM_NAME
 # Program args
+MOZJPEG_ARGS = ['mozjpeg']
 JPEGTRAN_ARGS = ['jpegtran', '-optimize']
 JPEGRESCAN_ARGS = ['jpegrescan']
 OPTIPNG_ARGS = ['optipng', '-o6', '-fix', '-preserve', '-force', '-quiet']
@@ -61,8 +62,8 @@ ALL_FORMATS = ALL_DEFAULT_FORMATS | COMIC_FORMATS
 NONE_FORMAT = 'NONE'
 ERROR_FORMAT = 'ERROR'
 # Programs
-PROGRAMS = ('optipng', 'pngout', 'jpegrescan', 'jpegtran', 'gifsicle',
-            'advpng')
+PROGRAMS = ('optipng', 'pngout', 'mozjpeg', 'jpegrescan', 'jpegtran',
+            'gifsicle', 'advpng')
 RECORD_FILENAME = '.%s_timestamp' % PROGRAM_NAME
 if sys.version > '3':
     LongInt = int
@@ -151,7 +152,7 @@ def program_reqs(arguments):
         setattr(arguments, program_name, val)
 
     do_png = arguments.optipng or arguments.pngout or arguments.advpng
-    do_jpeg = arguments.jpegrescan or arguments.jpegtran
+    do_jpeg = arguments.mozjpeg or arguments.jpegrescan or arguments.jpegtran
 
     do_comics = arguments.comics
 
@@ -169,11 +170,11 @@ def get_arguments():
     parser.add_argument("-r", "--recurse", action="store_true",
                         dest="recurse", default=0,
                         help="Recurse down through directories ignoring the"
-                             "image file arguments on the command line")
+                        "image file arguments on the command line")
     parser.add_argument("-v", "--verbose", action="count",
                         dest="verbose", default=0,
                         help="Display more output. -v (default) and -vv "
-                             "(noisy)")
+                        "(noisy)")
     parser.add_argument("-Q", "--quiet", action="store_const",
                         dest="verbose", const=-1,
                         help="Display little to no output")
@@ -186,9 +187,8 @@ def get_arguments():
     parser.add_argument("-f", "--formats", action="store", dest="formats",
                         default=DEFAULT_FORMATS,
                         help="Only optimize images of the specifed '%s' "
-                             "delimited formats from: %s" %
-                             (FORMAT_DELIMETER,
-                              ', '.join(sorted(ALL_FORMATS))))
+                        "delimited formats from: %s" %
+                        (FORMAT_DELIMETER, ', '.join(sorted(ALL_FORMATS))))
     parser.add_argument("-O", "--disable_optipng", action="store_false",
                         dest="optipng", default=1,
                         help="Do not optimize with optipng")
@@ -202,6 +202,9 @@ def get_arguments():
                         dest="jpegtran_prog", default=1,
                         help="Don't try to reduce size by making "
                         "progressive JPEGs with jpegtran")
+    parser.add_argument("-Z", "--disable_mozjpeg", action="store_false",
+                        dest="mozjpeg", default=1,
+                        help="Do not optimize with mozjpeg")
     parser.add_argument("-T", "--disable_jpegtran", action="store_false",
                         dest="jpegtran", default=1,
                         help="Do not optimize with jpegtran")
@@ -212,29 +215,29 @@ def get_arguments():
                         dest="to_png_formats",
                         const=PNG_FORMATS, default=PNG_CONVERTABLE_FORMATS,
                         help="Do not convert other lossless formats like "
-                             " %s to PNG when optimizing. By default, %s"
-                             " does convert these formats to PNG" %
-                             (', '.join(LOSSLESS_FORMATS), PROGRAM_NAME))
+                        " %s to PNG when optimizing. By default, %s"
+                        " does convert these formats to PNG" %
+                        (', '.join(LOSSLESS_FORMATS), PROGRAM_NAME))
     parser.add_argument("-S", "--disable_follow_symlinks",
-                              action="store_false",
+                        action="store_false",
                         dest="follow_symlinks", default=1,
                         help="disable following symlinks for files and "
-                             "directories")
+                        "directories")
     parser.add_argument("-d", "--dir", action="store", dest="dir",
                         default=os.getcwd(),
                         help="Directory to change to before optimiziaton")
     parser.add_argument("-b", "--bigger", action="store_true",
                         dest="bigger", default=0,
                         help="Save optimized files that are larger than "
-                             "the originals")
+                        "the originals")
     parser.add_argument("-t", "--record_timestamp", action="store_true",
                         dest="record_timestamp", default=0,
                         help="Store the time of the optimization of full "
-                             "directories in directory local dotfiles.")
+                        "directories in directory local dotfiles.")
     parser.add_argument("-D", "--optimize_after", action="store",
                         dest="optimize_after", default=None,
                         help="only optimize files after the specified "
-                             "timestamp. Supercedes -t")
+                        "timestamp. Supercedes -t")
     parser.add_argument("-N", "--noop", action="store_true",
                         dest="test", default=0,
                         help="Do not replace files with optimized versions")
@@ -280,7 +283,7 @@ def process_arguments(arguments):
             exit(1)
 
     # Make a rough guess about weather or not to invoke multithreding
-    # jpegrtan '-t' uses three threads
+    # jpegrescan '-t' uses three threads
     # one off multithread switch bcaseu this is the only one right now
     files_in_paths = 0
     non_file_in_paths = False
@@ -346,6 +349,18 @@ def gifsicle(ext_args):
     run_ext(args)
 
 
+def mozjpeg(ext_args):
+    """create argument list for mozjpeg"""
+    args = copy.copy(MOZJPEG_ARGS)
+    if ext_args.arguments.destroy_metadata:
+        args += ["-copy", "none"]
+    else:
+        args += ["-copy", "all"]
+    args += ['-outfile']
+    args += [ext_args.new_filename, ext_args.old_filename]
+    run_ext(args)
+
+
 def jpegtran(ext_args):
     """create argument list for jpegtran"""
     args = copy.copy(JPEGTRAN_ARGS)
@@ -471,7 +486,10 @@ def optimize_png(filename, arguments):
 def optimize_jpeg(filename, arguments):
     """run EXTERNAL programs to optimize jpeg formats"""
     final_filename = filename
-    if arguments.jpegrescan:
+    if arguments.mozjpeg:
+        report_stats = optimize_image_external(
+            final_filename, arguments, mozjpeg)
+    elif arguments.jpegrescan:
         report_stats = optimize_image_external(
             final_filename, arguments, jpegrescan)
     elif arguments.jpegtran_prog or arguments.jpegtran:
@@ -496,7 +514,8 @@ def optimize_image(arg):
                               arguments.pngout):
             report_stats = optimize_png(filename, arguments)
         elif is_format_selected(image_format, JPEG_FORMATS, arguments,
-                                arguments.jpegrescan or arguments.jpegtran):
+                                arguments.mozjpeg or arguments.jpegrescan
+                                or arguments.jpegtran):
             report_stats = optimize_jpeg(filename, arguments)
         elif is_format_selected(image_format, GIF_FORMATS, arguments,
                                 arguments.gifsicle):
@@ -611,7 +630,7 @@ def detect_file(filename, arguments):
 
     if arguments.verbose > 1 and not arguments.list_only:
         print(filename, image_format, 'is not a enabled image or '
-                                      'comic archive type.')
+              'comic archive type.')
 
 
 def get_archive_tmp_dir(filename):
@@ -892,7 +911,8 @@ def report_totals(bytes_in, bytes_out, arguments, nag_about_gifs):
             print("Didn't optimize any files.")
 
     if nag_about_gifs and arguments.verbose:
-        print("You should really convert animated GIFS to HTML5 video")
+        print("Most animated GIFS would be better off converted to"
+              " HTML5 video")
 
 
 def optimize_files_after(path, arguments, file_list, multiproc):
